@@ -2,5 +2,5 @@
 Code to provide a canvas to render to.
 """
 
-from .base import WgpuCanvasInterface, WgpuCanvasBase  # noqa: F401
+from .base import WgpuCanvasInterface, WgpuCanvasBase, WgpuAutoGui  # noqa: F401
 from ._offscreen import WgpuOffscreenCanvas  # noqa: F401
